@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 #
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -18,11 +17,11 @@ import re
 from keystonemiddleware import auth_token
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_utils import importutils
 from pecan import hooks
 
 from solum.common import context
-from solum.openstack.common.gettextutils import _
-from solum.openstack.common import importutils
+from solum.i18n import _
 
 
 LOG = logging.getLogger(__name__)
