@@ -13,9 +13,11 @@
 # under the License.
 
 import datetime
-import uuid
+import json
 
 from oslo_config import cfg
+from oslo_log import log as logging
+from oslo_utils import uuidutils
 
 from solum.api.handlers import handler
 from solum.common import exception
@@ -23,9 +25,12 @@ from solum.common import repo_utils
 from solum import objects
 from solum.objects import image
 from solum.objects.sqlalchemy import workflow
-from solum.openstack.common import log as logging
 from solum.worker import api as worker_api
 
+
+LOG = logging.getLogger(__name__)
+
+
 API_SERVICE_OPTS = [
     cfg.StrOpt('image_format',
                default='qcow2',
@@ -46,14 +51,11 @@ def list_opts():
     yield 'api', API_SERVICE_OPTS
 
 
-LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 CONF.register_opts(API_SERVICE_OPTS, group='api')
 
 IMAGE_STATES = image.States
 
-LOG = logging.getLogger(__name__)
-
 
 class WorkflowHandler(handler.Handler):
     """Fulfills a request on the workflow resource."""
@@ -110,8 +112,9 @@ class WorkflowHandler(handler.Handler):
 
     def create(self, data, commit_sha, status_url, du_id):
         """Create a new workflow."""
+
         db_obj = objects.registry.Workflow()
-        db_obj.id = str(uuid.uuid4())
+        db_obj.id = uuidutils.generate_uuid()
         db_obj.user_id = self.context.user
         db_obj.project_id = self.context.tenant
         db_obj.deleted = False
@@ -128,6 +131,15 @@ class WorkflowHandler(handler.Handler):
         app_obj = objects.registry.App.get_by_id(self.context,
                                                  db_obj.app_id)
 
+        if str(app_obj.languagepack).lower() == 'false' and not du_id:
+            msg = ("App {app} registered without a languagepack and no "
+                   "du id specified. Either register the app with"
+                   " a languagepack, or if there is already a pre"
+                   "built du for the app, specify its id with --du-id"
+                   " command line flag.")
+            msg = msg.format(app=app_obj.name)
+            raise exception.BadRequest(reason=msg)
+
         self._update_app_scale_config(app_obj, data)
 
         plan, assem = PlanAssemblyAdapter(self.context,
@@ -139,7 +151,8 @@ class WorkflowHandler(handler.Handler):
         workflow.Workflow.insert(self.context, db_obj)
 
         self._execute_workflow_actions(db_obj, app_obj, assem,
-                                       commit_sha=app_obj.source['revision'],
+                                       commit_sha=commit_sha,
+                                       status_url=status_url,
                                        du_id=du_id)
 
         # TODO(devkulkarni): Update status of actions
@@ -165,7 +178,7 @@ class WorkflowHandler(handler.Handler):
         image.source_uri = wf_obj.source['repository']
         image.base_image_id = app_obj.languagepack
         image.image_format = CONF.api.image_format
-        image.uuid = str(uuid.uuid4())
+        image.uuid = uuidutils.generate_uuid()
         image.user_id = self.context.user
         image.project_id = self.context.tenant
         image.status = IMAGE_STATES.QUEUED
@@ -175,8 +188,21 @@ class WorkflowHandler(handler.Handler):
 
         ports = app_obj.ports
 
-        # TODO(devkulkarni): Parse repo token from app description
-        repo_token = ''
+        app_raw_content = json.loads(app_obj.raw_content)
+        if ('repo_token' in app_raw_content):
+            repo_token = app_raw_content['repo_token']
+        else:
+            repo_token = ''
+
+        if ('private' in wf_obj.source.keys()):
+            private = wf_obj.source['private']
+        else:
+            private = False
+
+        if ('private_ssh_key' in wf_obj.source.keys()):
+            private_ssh_key = wf_obj.source['private_ssh_key']
+        else:
+            private_ssh_key = ''
 
         # TODO(devkulkarni): Check whether we need image.source_format
         image.source_format = 'solum'
@@ -185,7 +211,9 @@ class WorkflowHandler(handler.Handler):
             'source_url': image.source_uri,
             'commit_sha': commit_sha,
             'repo_token': repo_token,
-            'status_url': status_url
+            'status_url': status_url,
+            'private': private,
+            'private_ssh_key': private_ssh_key
         }
 
         if test_cmd:
@@ -207,7 +235,7 @@ class WorkflowHandler(handler.Handler):
             du_id=du_id)
 
 
-class PlanAssemblyAdapter():
+class PlanAssemblyAdapter(object):
     """Plan and assembly adapter."""
     # Adapter that we use to create assembly and plan
     # objects. This is intended to smooth the transition
@@ -228,19 +256,24 @@ class PlanAssemblyAdapter():
         self.app_obj = app_obj
 
     def create_dummies(self):
-        plan = objects.registry.Plan()
-        plan.uuid = self.app_obj.id
-        plan.user_id = self.context.user
-        plan.project_id = self.context.tenant
-        plan.name = self.app_obj.name
-        plan.create(self.context)
+        # Create only one plan
+        try:
+            plan = objects.registry.Plan.get_by_uuid(self.context,
+                                                     self.app_obj.id)
+        except exception.ResourceNotFound:
+            plan = objects.registry.Plan()
+            plan.uuid = self.app_obj.id
+            plan.user_id = self.context.user
+            plan.project_id = self.context.tenant
+            plan.name = self.app_obj.name
+            plan.create(self.context)
 
         assembly = objects.registry.Assembly()
         assembly.plan_id = plan.id
         assembly.user_id = self.context.user
         assembly.project_id = self.context.tenant
         assembly.name = self.app_obj.name
-        assembly.uuid = str(uuid.uuid4())
+        assembly.uuid = uuidutils.generate_uuid()
 
         assembly.workflow = self.wf_obj.actions
 
