@@ -20,11 +20,19 @@ from solum.tests import base
 solum.TLS.trace = trace_data.TraceData()
 
 # Just putting highly recognizable values in context
-CONTEXT = context.RequestContext(
-    '_auth_token_', '_user_', '_tenant_', '_domain_', '_user_domain_',
-    '_project_domain_', '_is_admin_', '_read_only_', '_request_id_',
-    '_user_name_', '_roles_', '_auth_url_',
-    auth_token_info='_auth_token_info_')
+CONTEXT = context.RequestContext(auth_token='_auth_token_',
+                                 user='_user_',
+                                 tenant='_tenant_',
+                                 domain='_domain_',
+                                 user_domain='_user_domain_',
+                                 project_domain='_project_domain_',
+                                 is_admin=False,
+                                 read_only=False,
+                                 request_id='_request_id_',
+                                 user_name='_user_name_',
+                                 roles='_roles_',
+                                 auth_url='_auth_url_',
+                                 auth_token_info='_auth_token_info_')
 
 
 class TestTraceData(base.BaseTestCase):
@@ -48,20 +56,21 @@ class TestTraceData(base.BaseTestCase):
             solum.TLS.trace._user_data,
             {'user': '_user_', 'tenant': '_tenant_'})
         self.assertEqual(({
+            'auth_token_info': '_auth_token_info_',
+            'auth_url': '_auth_url_',
             'domain': '_domain_',
-            'instance_uuid': None,
-            'is_admin': '_is_admin_',
+            'global_request_id': None,
+            'is_admin': False,
+            'is_admin_project': True,
             'project_domain': '_project_domain_',
-            'read_only': '_read_only_',
+            'read_only': False,
+            'resource_uuid': None,
             'roles': '_roles_',
             'show_deleted': False,
             'user_domain': '_user_domain_',
-            'user_identity': '_user_ _tenant_ _domain_ '
+            'user_identity': u'_user_ _tenant_ _domain_ '
             '_user_domain_ _project_domain_',
-            'user_name': '_user_name_',
-            'auth_url': '_auth_url_',
-            'auth_token_info': '_auth_token_info_'
-        }), solum.TLS.trace._support_data)
+            'user_name': '_user_name_'}), solum.TLS.trace._support_data)
 
     def test_info_commands(self):
         """Test trace setting functions."""
